@@ -390,7 +390,7 @@ class TexasHoldEm:
         self.pots.insert(pot_id + 1, split_pot)
 
         for player_id in self.in_pot_iter():
-            if self.players[player_id].chips >= self.chips_to_call(player_id):
+            if self.players[player_id].chips > self.chips_to_call(player_id):
                 self.players[player_id].last_pot += 1
 
     def _player_post(self, player_id: int, amount: int):
@@ -441,11 +441,11 @@ class TexasHoldEm:
     def _get_pot(self, pot_id: int) -> Pot:
         """
         Arguments:
-            pot_id (int): The player_id of the pot to get
+            pot_id (int): The id of the pot to get
         Returns:
-            Pot: The pot with given player_id
+            Pot: The pot with given id
         Raises:
-            ValueError: If a pot with player_id pot_id does not exist.
+            ValueError: If a pot with id pot_id does not exist.
 
         """
         if pot_id >= len(self.pots):
